@@ -9,7 +9,7 @@ logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
 
 def scan_host(ip_addr, start_port, end_port):
     check_arguments(ip_addr, start_port, end_port)
-    print('[*] Starting TCP port scan on host %s' % ip_addr)
+    logging.info('[*] Starting TCP port scan on host %s' % ip_addr)
     # Begin TCP scan on host
     tcp_scan(ip_addr, start_port, end_port)
     logging.info('[+] TCP scan on host %s complete' % ip_addr)
@@ -29,25 +29,25 @@ def tcp_scan(ip_addr, start_port, end_port):
         try:
             tcp = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             if not tcp.connect_ex((ip_addr, port)):
-                print('[+] %s:%d/TCP Open' % (ip_addr, port))
+                logging.info('[+] %s:%d/TCP Open' % (ip_addr, port))
                 tcp.close()
         except Exception as e:
-            print(e)
+            logging.error(e)
 
 
 def check_arguments(ip_addr, start_port, end_port):
     try:
         ipaddress.ip_address(ip_addr)
     except ValueError:
-        sys.exit("Argument 1 not a valid IP address.")
+        logging.error("Argument 1 not a valid IP address.")
 
     try:
         x = int(start_port)
     except ValueError:
-        sys.exit("Argument 2 not a valid port number.")
+        logging.error("Argument 2 not a valid port number.")
 
     try:
         y = int(end_port)
     except ValueError:
-        sys.exit("Argument 3 not a valid port number.")
-    print("Arguments valid, starting scan.")
+        logging.error("Argument 3 not a valid port number.")
+    logging.info("Star-Scan arguments valid, starting scan.")
